package com.goldenwater.slaj.stan.service;

import java.util.List;
import com.goldenwater.slaj.stan.domain.BisStanCertChaAppl;

public interface IBisStanCertChaApplService {
    BisStanCertChaAppl selectBisStanCertChaApplByGuid(String guid);
    List<BisStanCertChaAppl> selectBisStanCertChaApplList(BisStanCertChaAppl entity);
    int insertBisStanCertChaAppl(BisStanCertChaAppl entity);
    int updateBisStanCertChaAppl(BisStanCertChaAppl entity);
    int deleteBisStanCertChaApplByGuid(String guid);
    int deleteBisStanCertChaApplByGuids(String[] guids);
}
